Attempts to read bytes from the given reader and interpret them as a Value.
Errors
This function will return Error on any I/O error while either reading or decoding a Value.
All instances of ErrorKind::Interrupted are handled by this function and the underlying
operation is retried.