Function rmpv::encode::write_value
source · [−]Expand description
Encodes and attempts to write the most efficient representation of the given Value.
Note
All instances of ErrorKind::Interrupted are handled by this function and the underlying
operation is retried.