Struct rmpv::Utf8StringRef
source · [−]pub struct Utf8StringRef<'a> { /* private fields */ }Expand description
A non-owning evil twin of Utf8String. Does exactly the same thing except ownership.
Implementations
sourceimpl<'a> Utf8StringRef<'a>
impl<'a> Utf8StringRef<'a>
sourcepub fn as_str(&self) -> Option<&str>
pub fn as_str(&self) -> Option<&str>
Returns the string reference if the string is valid UTF-8, or else None.
sourcepub fn as_err(&self) -> Option<&Utf8Error>
pub fn as_err(&self) -> Option<&Utf8Error>
Returns the underlying Utf8Error if the string contains invalud UTF-8 sequence, or
else None.
sourcepub fn as_bytes(&self) -> &[u8]ⓘNotable traits for &mut [u8]impl Write for &mut [u8]impl Read for &[u8]
pub fn as_bytes(&self) -> &[u8]ⓘNotable traits for &mut [u8]impl Write for &mut [u8]impl Read for &[u8]
Returns a byte slice of this string contents no matter whether it’s valid or not UTF-8.